==> exFrame-0.8.6.zip: exFrame/include/class.exFrame.php <==
<?php
/**
@version $Id$
*/

class exFrame {

	/**
	@brief 쥸ȥѥϥɥ
	*/
	function &getRegistryHandler() {
		global $xoopsDB;
		global $__exframe_handler_cache__;
		if(!isset($__exframe_handler_cache__['registry'])) {
			if(!class_exists("exregistryobjecthandler"))
				require_once "exTra/Registry.php";
			$__exframe_handler_cache__['registry']= new exRegistryObjectHandler($xoopsDB,"exregistryobjecthandler");
		}
		return $__exframe_handler_cache__['registry'];
	}

	// ---------
	// functions
	// ---------

	/**
	@brief ߤΥꥯȥ᥽åɤĴ POST ɤ֤饹᥽å
	*/
	function isPost() {
		return $_SERVER['REQUEST_METHOD']=='POST';
	}

	/**
	@brief ߤΥꥯȥ᥽åɤĴ GET ɤ֤饹᥽å
	*/
	function isGet() {
		return $_SERVER['REQUEST_METHOD']=='GET';
	}

	/**
	@brief ԤΤȤͤɽ
	*/
	function debug($val) {
		global $xoopsUser;
		if(is_object($xoopsUser)) {
    		if($xoopsUser->isAdmin()){
    			print nl2br(var_dump($val));
    			print "<br>";
    		}
		}
	}

	/**
	@brief XoopsFormDateTime Ǽͤ unixtime ֤ޤ
	*/
	function decodeXoopsFormDateTime($arr) {
		if(isset($arr['date']) && isset($arr['time'])) {
			$tmp=explode('-',$arr['date']);
			return mktime(0,0,0,$tmp[1],$tmp[2],$tmp[0])+$arr['time'];
		}
		else {
			return 0;
		}
	}

	function file_get_contents($file) {
		if(!file_exists($file)) return false;

		if(function_exists("file_get_contents")) {
			return file_get_contents($file);
		}
		else {
			$ret="";

    		$fp=fopen($file,"r");
    		if(!$fp) return false;
    
			while($ret.=fread($fp,4096));
			
    		fclose($fp);
    		
    		return ($ret);
		}
	}

	function InjectionCheck($key) {
		return isset($_GET[$key]) || isset($_POST[$key]) || isset($_COOKIE[$key]) || isset($_SESSION[$key]);
	}
}

?>

==> exFrame-0.8.7.zip: exFrame/include/class.exFrame.php <==
<?php
/**
@version $Id$
*/

class exFrame {

	/**
	@brief 쥸ȥѥϥɥ
	*/
	function &getRegistryHandler() {
		global $xoopsDB;
		global $__exframe_handler_cache__;
		if(!isset($__exframe_handler_cache__['registry'])) {
			if(!class_exists("exregistryobjecthandler"))
				require_once "exTra/Registry.php";
			$__exframe_handler_cache__['registry']= new exRegistryObjectHandler($xoopsDB,"exregistryobjecthandler");
		}
		return $__exframe_handler_cache__['registry'];
	}

	// ---------
	// functions
	// ---------

	/**
	@brief ߤΥꥯȥ᥽åɤĴ POST ɤ֤饹᥽å
	*/
	function isPost() {
		return $_SERVER['REQUEST_METHOD']=='POST';
	}

	/**
	@brief ߤΥꥯȥ᥽åɤĴ GET ɤ֤饹᥽å
	*/
	function isGet() {
		return $_SERVER['REQUEST_METHOD']=='GET';
	}

	/**
	@brief ԤΤȤͤɽ
	*/
	function debug($val) {
		global $xoopsUser;
		if(is_object($xoopsUser)) {
    		if($xoopsUser->isAdmin()){
    			print nl2br(var_dump($val));
    			print "<br>";
    		}
		}
	}

	/**
	@brief XoopsFormDateTime Ǽͤ unixtime ֤ޤ
	*/
	function decodeXoopsFormDateTime($arr) {
		if(isset($arr['date']) && isset($arr['time'])) {
			$tmp=explode('-',$arr['date']);
			return mktime(0,0,0,$tmp[1],$tmp[2],$tmp[0])+$arr['time'];
		}
		else {
			return 0;
		}
	}

	function file_get_contents($file) {
		if(!file_exists($file)) return false;

		if(function_exists("file_get_contents")) {
			return file_get_contents($file);
		}
		else {
			$ret="";

    		$fp=fopen($file,"r");
    		if(!$fp) return false;
    
			while($ret.=fread($fp,4096));
			
    		fclose($fp);
    		
    		return ($ret);
		}
	}

	function InjectionCheck($key) {
		return isset($_GET[$key]) || isset($_POST[$key]) || isset($_COOKIE[$key]) || isset($_SESSION[$key]);
	}

	function appendObjects(&$tpl,$name,&$objects) {
		foreach($objects as $obj) {
			$tpl->append(name,$obj->getStructure());
		}
	}

}

?>
